@@ -113,6 +113,9 @@ class TestCDIRunner(unittest.TestCase):
                     ["support_threshold=0.25", "verbose=10"],
                     ["support_threshold=0.24,0.26", "verbose=10"],
                     ["support_threshold=0.24,0.26", "nb_run=2", "verbose=10"],
+                    ["support_post_expand=-1,2"],
+                    ["support_post_expand=2,-1"],
+                    ["support_post_expand=2,1"]
                     ]
         # Also test all options as saved in a *.txt file
         voptions += [v + ["as_parameters_file"] for v in voptions]
@@ -180,6 +183,9 @@ class TestCDIRunner(unittest.TestCase):
                             ["--support_threshold", "0.25", "--verbose", "10"],
                             ["--support_threshold", "0.24", "0.26", "--verbose", "10"],
                             ["--support_threshold", "0.24", "0.26", "--nb_run", "2", "--verbose", "10"],
+                            ["--support_post_expand=-1,2"],
+                            ["--support_post_expand", "2,-1"],
+                            ["--support_post_expand", "2", "1"]
                             ]:
                 option_string = ""
                 for s in options:
@@ -242,7 +248,13 @@ class TestCDIRunner(unittest.TestCase):
                     ["support_size=50"], ["support_size=50 support=circle"],
                     ["support_size=50 support=square"], ["support_only_shrink"], ["support_update_border_n=3"],
                     ["rebin=2"], ["rebin=2,1"], ["nb_run=3", "nb_run_keep=1"], ["mask_interp=16,2"],
-                    ["support=%s" % support_path1], ["support=%s" % support_path2], ["support=%s" % support_path3]]
+                    ["support=%s" % support_path1],
+                    ["support=%s" % support_path2],
+                    ["support=%s" % support_path3],
+                    ["support_post_expand=-1,2"],
+                    ["support_post_expand=2,-1"],
+                    ["support_post_expand=2,1"]
+                    ]
         for my_env, options in zip(self.my_envs, voptions):
             option_string = ""
             for s in options:
@@ -274,8 +286,13 @@ class TestCDIRunner(unittest.TestCase):
                     ["--support_only_shrink"], ["--support_update_border_n", "3"],
                     ["--rebin", "2"], ["--rebin", "2", "1"], ["--nb_run", "3", "--nb_run_keep", "1"],
                     ["--mask_interp", "16", "2"],
-                    ["--support", "%s" % support_path1], ["--support", "%s" % support_path2],
-                    ["--support", "%s" % support_path3]]
+                    ["--support", "%s" % support_path1],
+                    ["--support", "%s" % support_path2],
+                    ["--support", "%s" % support_path3],
+                    ["--support_post_expand=-1,2"],
+                    ["--support_post_expand", "2,-1"],
+                    ["--support_post_expand", "2", "1"]
+                    ]
         for my_env, options in zip(self.my_envs, voptions):
             option_string = ""
             for s in options:
@@ -498,6 +515,7 @@ class TestCDIRunner(unittest.TestCase):
                         ['--prtf'],
                         ['--modes', '--prtf', '--average'],
                         ['--modes', '--real'],
+                        ['--modes', '--modes_output', 'modes.h5'],
                         ]:
             with self.subTest(options=options, command=' '.join(args + options)):
                 with subprocess.Popen(args + options, stderr=subprocess.PIPE,
@@ -545,6 +563,7 @@ class TestCDIRunner(unittest.TestCase):
                         ['prtf'],
                         ['modes', 'prtf', 'average'],
                         ['modes', 'real'],
+                        ['modes', 'modes_output=modes.h5'],
                         ]:
             with self.subTest(options=options, command=' '.join(args + options)):
                 with subprocess.Popen(args + options, stderr=subprocess.PIPE,
