@@ -460,6 +460,16 @@ class TestScattering(unittest.TestCase):
             import_ok = False
         self.assertTrue(import_ok, msg=msg)
 
+    @unittest.skipIf('86' not in platform.machine(), "Not testing for SSE code on non-x86 archs")
+    def test_scattering_cpu_import(self):
+        msg = "Testing for SSE cpu scattering module"
+        try:
+            from pynx.scattering import cpu
+            import_ok = True
+        except ImportError:
+            import_ok = False
+        self.assertTrue(import_ok, msg=msg)
+
     def test_fhkl_cpu(self):
         if scattering.fhkl.has_cython_scattering:
             s = 'cython'
